require 'spec_helper'

describe 'puppet_enterprise::profile::console::console_services_config' do
  before :all do
    @facter_facts = {
      'osfamily'          => 'Debian',
      'operatingsystem'   => 'Debian',
      'lsbmajdistrelease' => '6',
      'puppetversion'     => '3.6.2 (Puppet Enterprise 3.3.0)',
      'is_pe'             => 'true',
      'fqdn'              => 'console.rspec',
      'clientcert'        => 'awesomecert',
      'pe_concat_basedir'    => '/tmp/file',
    }

    @params = { 'certname' => 'console_services.rspec',
                'classifier_url_prefix' => '/classifier-api', }
  end

  let(:facts) { @facter_facts }
  let(:params) { @params }
  let(:confdir) { '/etc/puppetlabs/console-services' }
  let(:cert_dir) { '/opt/puppet/share/console-services/certs' }

  context "when the parameters are valid" do
    it { should contain_file("#{confdir}/conf.d/global.conf")
      .with_content(%r[logging-config:\s* /etc/puppetlabs/console-services/logback\.xml\s*login-path:\s*"/auth/login"]) }
    it { should contain_file("#{confdir}/bootstrap.cfg") }
    it { should contain_pe_concat("#{confdir}/bootstrap.cfg") }
  end

  context "when configuring jetty SSL" do
    let(:file) { "#{confdir}/conf.d/webserver.conf" }
    it { should contain_file(file)
      .with_content(%r[console: {\n\s+access-log-config: /etc/puppetlabs/console-services/request-logging.xml\n\s+host: 127.0.0.1,\n\s+port: 4430,\n]) }
    it { should contain_file(file)
      .with_content(%r[api: {\n\s+access-log-config: /etc/puppetlabs/console-services/request-logging.xml\n\s+host: 127.0.0.1,\n\s+port: 4432,\n]) }
    it { should contain_file(file)
      .with_content(%r[\s*"puppetlabs\.classifier\.main/classifier-service": {\n\s*route:\s*"/classifier-api"]) }
    it { should contain_file(file).with_content(%r[ssl-cert: #{cert_dir}/console_services.rspec.cert.pem]) }
    it { should contain_file(file).with_content(%r[ssl-key: #{cert_dir}/console_services.rspec.private_key.pem]) }
    it { should contain_file(file).with_content(%r[ssl-ca-cert: /etc/puppetlabs/puppet/ssl/certs/ca.pem]) }
    it { should contain_file(file).with_content(/ssl-port: 4433/) }
    it { should contain_file(file).with_content(/client-auth: none/) }
    it { should_not contain_file(file).with_content(/max-threads\s*:\s*/) }
  end

  context "when specifying jetty max-threads" do
    let(:file) { "#{confdir}/conf.d/webserver.conf" }
    before :each do
      @params['tk_jetty_max_threads_api'] = 12
      @params['tk_jetty_max_threads_console'] = 34
    end
    it { should contain_file(file).with_content(/max-threads\s*:\s*12/) }
    it { should contain_file(file).with_content(/max-threads\s*:\s*34/) }
  end

  context "when specifying jetty request-header-max-size" do
    let(:file) { "#{confdir}/conf.d/webserver.conf" }
    it { should contain_file(file).with_content(/request-header-max-size\s*:\s*12/) }
  end
end
